( cd usr/bin ; rm -rf gnome-help )
( cd usr/bin ; ln -sf yelp gnome-help )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/yelp.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
